Welcome to ArrayLSTM's documentation!
=====================================

ArrayLSTM provides a pytorch implementation of `Recurrent Memory Array Structures by Kamil M Rocki`_.
This code was implemented as part of the IEEE S&P 2022 `DeepCASE: Semi-Supervised Contextual Analysis of Security Events`_ paper.
We ask people to cite both works when using the software for academic research papers, see :ref:`Citing` for more information.

_`Recurrent Memory Array Structures by Kamil M Rocki`: https://arxiv.org/abs/1607.03085

_`IEEE S&P 2022 DeepCASE: Semi-Supervised Contextual Analysis of Security Events paper.`: https://vm-thijs.ewi.utwente.nl/static/homepage/papers/deepcase.pdf

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage/usage
   reference/reference
   license
   citing
